@@ -10,7 +10,7 @@ from FLF.exceptions import ProcedureExecutionException
 
 class Store:
     def __init__(self, callback):
-        self.store = {}
+        self.store = dict()
         self.callback = callback
 
     def add(self, key, name, value, size, mask, call_procedure, reply_to, req_id):
@@ -23,7 +23,8 @@ class Store:
         else:
             self.store[req_id]["files"][name] = value
 
-        if self.store[req_id]["mask"] == (2 ** size - 1):
+        full_mask = (1 << size) - 1
+        if self.store[req_id]["mask"] == full_mask:
             result = self.store.pop(req_id)
             result.pop("mask")
             self.on_request_complete(result, key, call_procedure, reply_to, req_id)
@@ -141,9 +142,9 @@ class RpcServer:
 
         # if server has needed procedure
         if call_procedure in self.procedures:
+            self.channel.basic_ack(delivery_tag=method.delivery_tag)
             self.on_request(request_size, request_mask, batch_name, correlation_id, reply_to,
                             call_procedure, body, req_id)
-            self.channel.basic_ack(delivery_tag=method.delivery_tag)
         else:
             self.channel.basic_nack(delivery_tag=method.delivery_tag)
 
@@ -218,7 +219,10 @@ class RpcConnector:
         req_id = props.headers["req_id"]
 
         if self.correlation_id == correlation_id:
+            self.channel.basic_ack(delivery_tag=method.delivery_tag)
             self.on_response(request_size, request_mask, batch_name, correlation_id, body, req_id)
+        else:
+            self.channel.basic_nack(delivery_tag=method.delivery_tag)
 
     def on_complete_callback(self, data, key, call_procedure, reply_to, req_id):
         self.response = data
@@ -242,11 +246,12 @@ class RpcConnector:
 
             while not self.response:
                 self.connection.process_data_events()
+            self.response = self.response if self.response else dict()
 
             return self.response["params"], self.response["files"]
         except Exception as e:
             raise ProcedureExecutionException(f"Failed to execute procedure '{name}': {str(e)}\n" +
-                                              "{traceback.format_exc()}")
+                                              f"{traceback.format_exc()}")
 
     def connect(self):
         print("Rpc client connects to the queue server")
@@ -264,9 +269,8 @@ class RpcConnector:
         self.channel = self.connection.channel()
         result = self.channel.queue_declare(queue='', exclusive=True)
         self.callback_queue = result.method.queue
-        self.channel.basic_consume(queue=self.callback_queue, on_message_callback=self.on_message, auto_ack=True)
+        self.channel.basic_consume(queue=self.callback_queue, on_message_callback=self.on_message)
 
     def begin(self):
         self.connection = self.connect()
         self.create_channel()
-
